export declare interface PluralizeOptions {
  count?: number
  inclusive?: boolean
}
declare type Rule = [RegExp, string]
type StringOrRegExp = string | RegExp
declare interface PluralizeFunction {
  (word: string, options?: PluralizeOptions): string
  plural: (word: string) => string
  isPlural: (word: string) => boolean
  singular: (word: string) => string
  isSingular: (word: string) => boolean
  addPluralRule: (rule: StringOrRegExp, replacement: string) => void
  addSingularRule: (rule: StringOrRegExp, replacement: string) => void
  addUncountableRule: (word: string | RegExp) => void
  addIrregularRule: (single: string, plural: string) => void
}
declare const pluralRules: Rule[];
declare const irregularPlurals: Record<string, string>;
declare function sanitizeRule(rule: string | RegExp): RegExp;
declare function restoreCase(word: string, token: string): string;
declare function interpolate(str: string, ...args: any[]): string;
declare function replace(word: string, rule: Rule): string;
declare function sanitizeWord(token: string, word: string, rules: Rule[]): string;
declare function replaceWord(replaceMap: Record<string, string>, keepMap: Record<string, string>, rules: Rule[]): (word: string) => string { return (word: string) => { const token = word.toLowerCase() if (keepMap[token]) return restoreCase(word, token) if (replaceMap[token]) return restoreCase(word, replaceMap[token]) return sanitizeWord(token, word, rules) } };
declare function checkWord(replaceMap: Record<string, string>, keepMap: Record<string, string>, rules: Rule[]): (word: string) => boolean { return (word: string) => { const token = word.toLowerCase() if (keepMap[token]) return true if (replaceMap[token]) return false return sanitizeWord(token, token, rules) === token } };
export declare const pluralize: PluralizeFunction;
export declare const singular: PluralizeFunction;
export declare const plural: PluralizeFunction;
declare const lowerPlural: unknown;

export default pluralize;